@@ -293,7 +293,7 @@ class RoutingConnectionPool(AbstractConnectionPool):
             with self.acquire_direct(address) as cx:
                 _, _, server_version = (cx.server.agent or "").partition("/")
                 if server_version and Version.parse(server_version) >= Version((3, 2)):
-                    cx.run("CALL dbms.cluster.routing.getRoutingTable({context})",
+                    cx.run("CALL dbms.cluster.routing.getRoutingTable($context)",
                            {"context": self.routing_context}, on_success=metadata.update, on_failure=fail)
                 else:
                     cx.run("CALL dbms.cluster.routing.getServers", {}, on_success=metadata.update, on_failure=fail)
